Play the Game of Nim
====================

.. .. toctree::
    :maxdepth: 2
    :caption: Contents

    README.rst


Modules
=======

.. autosummary::
   :toctree: modules
    
   __init__
   core
   calculations
   typedefs
   version
   playing.cli.play
   playing.cli.ansi
   playing.demo


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
